@@ -1,10 +1,6 @@
 OC.L10N.register(
     "activity",
     {
-    "Activity" : "Actividá",
-    "An error occurred while loading activities" : "Asocedió un fallu entrín se cargaben les actividaes",
-    "No activity yet" : "Entá nun hai actividaes",
-    "Load more activities" : "Cargar más actividaes",
     "Copied!" : "¡Copióse!",
     "Not supported!" : "¡Nun se sofita!",
     "Press ⌘-C to copy." : "Primi ⌘-C pa copiar.",
@@ -17,24 +13,23 @@ OC.L10N.register(
     "There are no events for this filter" : "Nun hai eventos pa esta peñera",
     "Today" : "Güei",
     "Yesterday" : "Ayeri",
-    "Open file" : "Abrir ficheru",
     "Personal activity feed for %s" : "Feed d'actividá personal pa %s",
     "Your feed URL is invalid" : "La URL del to feed nun ye válida",
     "Your settings have been updated." : "Anováronse los tos axustes.",
     "Settings have been updated." : "Anováronse los axustes.",
+    "_and %n more _::_and %n more _" : ["y %n más","y %n más"],
     "All activities" : "Toles actividaes",
     "By others" : "Por otros",
     "By you" : "Por ti",
     "Hello %s" : "%sHola ",
     "Hello %s," : "Hola %s,",
     "There was some activity at %s" : "Hebo dalgo d'actividá en %s",
-    "_and %n more _::_and %n more _" : ["y %n más","y %n más"],
     "Mail" : "Corréu",
-    "Stream" : "Fluxu de rede",
+    "Activity" : "Actividá",
+    "Notifications" : "Notificaciones",
+    "No activity yet" : "Entá nun hai actividaes",
     "Activity feed" : "Feed d'actividá",
-    "Notify about your own actions via email" : "Avisar per corréu tocante a les mios propies aiciones",
     "You need to set up your email address before you can receive notification emails." : "Precises configurar la to direición de corréu enantes que pueas recibir correos d'avisu.",
-    "Send emails:" : "Unviar correos:",
     "As soon as possible" : "Namái que seya posible",
     "Hourly" : "Cada hora",
     "Daily" : "Caldía",
@@ -42,9 +37,8 @@ OC.L10N.register(
     "Settings" : "Axustes",
     "Enable RSS feed" : "Habilitar feed RSS",
     "No more events to load" : "Nun hai más eventos pa cargar",
-    "\"remote user\"" : "«usuariu remotu»",
-    ", " : ", ",
-    "%s and %s" : "%s y %s",
-    "Files" : "Ficheros"
+    "An error occurred while loading activities" : "Asocedió un fallu entrín se cargaben les actividaes",
+    "Load more activities" : "Cargar más actividaes",
+    "Open file" : "Abrir ficheru"
 },
 "nplurals=2; plural=(n != 1);");
