@@ -94,7 +94,7 @@ OC.L10N.register(
     "Username as share" : "Nombre de usuario como elemento compartido",
     "OpenStack Object Storage" : "OpenStack Object Storage",
     "Service name" : "Nombre del servicio",
-    "Request timeout (seconds)" : "Tiemo de vida de la solicitud (segudos)",
+    "Request timeout (seconds)" : "Tiemo de vida de la solicitud (segundos)",
     "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para cURL en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Favor de solicitar a su administador su instalación. ",
     "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para FTP en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Favor de solicitar a su administador su instalación. ",
     "External storage support" : "Soporte de almacenamiento externo",
