@@ -11,6 +11,7 @@ OC.L10N.register(
     "Generate keys" : "Luo avaimet",
     "Error generating key pair" : "Virhe luotaessa avainparia",
     "All users. Type to select user or group." : "Kaikki käyttäjät. Kirjoita valitaksesi käyttäjän tai ryhmän.",
+    "(Group)" : "(Ryhmä)",
     "Compatibility with Mac NFD encoding (slow)" : "Yhteensopivuus Mac NFD -enkoodauksen kanssa (hidas)",
     "Enable encryption" : "Käytä salausta",
     "Enable previews" : "Käytä esikatseluja",
@@ -101,8 +102,10 @@ OC.L10N.register(
     "SFTP" : "SFTP",
     "Root" : "Juurihakemisto",
     "SFTP with secret key login" : "SFTP salaisen avaimen kirjautumisella",
+    "SMB/CIFS" : "SMB/CIFS",
     "Share" : "Jaa",
     "Show hidden files" : "Näytä piilotiedostot",
+    "Verify ACL access when listing files" : "Vahvista ACL-pääsy tiedostoja listatessa",
     "Timeout" : "Aikakatkaisu",
     "Username as share" : "Käyttäjänimi jakona",
     "OpenStack Object Storage" : "OpenStack Object Storage",
