@@ -72,9 +72,8 @@ OC.L10N.register(
     "Wrong share ID, share doesn't exist" : "Id. de partilha errada, a partilha não existe",
     "Could not delete share" : "Não foi possível eliminar a partilha",
     "Please specify a file or folder path" : "Por favor, especifique um ficheiro ou caminho de pasta",
-    "Wrong path, file/folder doesn't exist" : "Caminho errado, ficheiro/pasta não existe",
+    "Wrong path, file/folder doesn't exist" : "Caminho errado, o arquivo ou pasta não existe",
     "Could not create share" : "Não foi possível criar partilha",
-    "invalid permissions" : "permissões inválidas",
     "Please specify a valid user" : "Por favor, especifique um utilizador válido",
     "Group sharing is disabled by the administrator" : "A partilha em grupo está desativada pelo administrador",
     "Please specify a valid group" : "Por favor, especifique um grupo válido",
@@ -88,11 +87,9 @@ OC.L10N.register(
     "Not a directory" : "Não é uma diretoria",
     "Could not lock path" : "Não foi possível bloquear o caminho",
     "Wrong or no update parameter given" : "Parâmetro indicado errado ou desatualizado",
-    "Can't change permissions for public share links" : "Não é possível alterar as permissões para as hiperligações de partilha pública",
     "shared by %s" : "partilhado por %s",
     "Download all files" : "Transferir todos os ficheiros",
     "Direct link" : "Hiperligação direta",
-    "Add to your Nextcloud" : "Adicionar à sua Nextcloud",
     "Share API is disabled" : "A partilha de API está desativada",
     "File sharing" : "Partilha de ficheiro",
     "Accept" : "Aceitar",
@@ -141,10 +138,13 @@ OC.L10N.register(
     "sharing is disabled" : "a partilha está desativada",
     "For more info, please ask the person who sent this link." : "Para mais informação, por favor, pergunte à pessoa que lhe enviou esta hiperligação.",
     "Share note" : "Partilhar nota",
-    "Download %s" : "Transferir %s",
     "Upload files to %s" : "Enviar ficheiros para %s",
     "Note" : "Nota",
     "Select or drop files" : "Seleccione ou solte ficheiros",
-    "Uploaded files:" : "Ficheiros enviados:"
+    "Uploaded files:" : "Ficheiros enviados:",
+    "Add to your Nextcloud" : "Adicionar à sua Nextcloud",
+    "invalid permissions" : "permissões inválidas",
+    "Can't change permissions for public share links" : "Não é possível alterar as permissões para as hiperligações de partilha pública",
+    "Download %s" : "Transferir %s"
 },
 "nplurals=2; plural=(n != 1);");
