@@ -103,7 +103,7 @@ OC.L10N.register(
     "Please specify a file or folder path" : "请指定一个文件或文件夹路径",
     "Wrong path, file/folder doesn't exist" : "路径错误，文件或文件夹不存在",
     "Could not create share" : "无法创建共享",
-    "invalid permissions" : "无效的权限",
+    "Invalid permissions" : "无效的权限 ",
     "Please specify a valid user" : "请指定一个有效的用户",
     "Group sharing is disabled by the administrator" : "群组共享已被管理员禁用",
     "Please specify a valid group" : "请指定一个有效的组",
@@ -113,6 +113,8 @@ OC.L10N.register(
     "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud Talk 没有启用，所以通过 Nextcloud Talk 发送 %s 共享密码失败。",
     "Invalid date, date format must be YYYY-MM-DD" : "无效的日期，日期格式必须是 YYYY-MM-DD",
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "共享 %1$s 失败，后端不允许类型为 %2$s 的共享",
+    "Please specify a valid federated user ID" : "请指定一个有效的联邦用户 ID",
+    "Please specify a valid federated group ID" : "请指定一个有效的联邦群组 ID",
     "You cannot share to a Circle if the app is not enabled" : "如果这个应用程序不可用，您不能共享到圈子",
     "Please specify a valid circle" : "请指明一个可用圈子",
     "Sharing %s failed because the back end does not support room shares" : "由于后端不支持房间共享，所以共享 %s 失败。",
@@ -121,12 +123,12 @@ OC.L10N.register(
     "Could not lock node" : "无法锁定节点",
     "Could not lock path" : "无法锁定路径",
     "Wrong or no update parameter given" : "错误或没有更新参数给出",
-    "Can't change permissions for public share links" : "不能改变公共共享链接权限",
-    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud Talk 没有启用，所以通过 Nextcloud Talk 发送共享密码失败。",
+    "Cannot change permissions for public share links" : "无法更改公共共享链接的权限 ",
+    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "“通过Nextcloud Talk发送密码”共享文件或文件夹失败了，因为未启用 Nextcloud Talk",
     "shared by %s" : "共享者 %s",
     "Download all files" : "下载所有文件",
     "Direct link" : "直接链接",
-    "Add to your Nextcloud" : "添加到您的 Nextcloud",
+    "Add to your %s" : "添加到你的 %s",
     "Share API is disabled" : "共享 API 已被禁用",
     "File sharing" : "文件共享",
     "Share will expire tomorrow" : "共享将在明天过期",
@@ -139,6 +141,13 @@ OC.L10N.register(
     "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "这个应用程序允许用户在 Nextcloud 内部共享文件。如果启用，管理员能够选择哪个组可以共享文件。然后，可用的用户能够共享文件和文件夹给 Nextcloud 中的其他用户和组。另外，如果管理员启用了共享链接功能，能够使用外部链接将文件共享给 Nextcloud 之外的其他用户。管理员也可以强制设置密码，过期日期，并且可以通过共享链接启用服务器到服务器的共享，以及从移动设备共享。\n关闭该功能将删除服务器上所有共享接收者以用同步客户端和移动应用上的共享文件和文件夹。更多信息可查阅 Nextcloud 文档。",
     "Sharing" : "共享",
     "Accept user and group shares by default" : "默认接受用户和分组共享",
+    "Error while toggling options" : "切换选项时出错",
+    "Set default folder for accepted shares" : "设置已接受共享的默认文件夹",
+    "Reset" : "重置",
+    "Reset folder to system default" : "重置文件夹为系统默认值",
+    "Choose a default folder for accepted shares" : "为已接受的共享选择一个默认文件夹",
+    "Invalid path selected" : "所选路径无效",
+    "Unknown error" : "未知错误",
     "Allow editing" : "允许编辑",
     "Allow creating" : "允许创建",
     "Allow deleting" : "允许删除",
@@ -174,7 +183,7 @@ OC.L10N.register(
     "Share label" : "分享标签",
     "Read only" : "只读",
     "Allow upload and editing" : "允许上传和编辑",
-    "File drop (upload only)" : "文件拖拽（仅上传）",
+    "File drop (upload only)" : "文件拖放（仅上传）",
     "Hide download" : "隐藏下载",
     "Password protect" : "密码保护",
     "Video verification" : "视频验证",
@@ -228,13 +237,17 @@ OC.L10N.register(
     "For more info, please ask the person who sent this link." : "欲知详情，请联系发给您该链接的人。",
     "Share note" : "共享笔记",
     "Toggle grid view" : "切换网格视图",
-    "Download %s" : "下载 %s",
     "Upload files to %s" : "上传文件到 %s",
     "Note" : "备注",
-    "Select or drop files" : "选择或删除文件",
+    "Select or drop files" : "选择或拖放文件",
     "Uploading files" : "正在上传文件",
     "Uploaded files:" : "上传的文件： ",
     "By uploading files, you agree to the %1$sterms of service%2$s." : "通过上传文件，您同意了 %1$s 服务条款 %2$s。",
-    "Name, email, or federated cloud ID …" : "名称，电子邮件或联合云 ID ..."
+    "Add to your Nextcloud" : "添加到您的 Nextcloud",
+    "invalid permissions" : "无效的权限",
+    "Can't change permissions for public share links" : "不能改变公共共享链接权限",
+    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud Talk 没有启用，所以通过 Nextcloud Talk 发送共享密码失败。",
+    "Name, email, or federated cloud ID …" : "名称，电子邮件或联合云 ID ...",
+    "Download %s" : "下载 %s"
 },
 "nplurals=1; plural=0;");
