@@ -7,7 +7,6 @@ OC.L10N.register(
     "Press ⌘-C to copy." : "‎⌘-C להעתקה.",
     "Press Ctrl-C to copy." : "Ctrl-C להעתקה.",
     "First run wizard" : "אשף ההפעלה הראשונית",
-    "Add your profile information! For example your email is needed to reset your password." : "נא להוסיף את פרטי הפרופיל שלך! למשל, כתובת הדוא״ל שלך נחוצה לטובת איפוס הססמה שלך.",
     "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "נא להוסיף את פרטי הפרופיל שלך! ניתן להגדיר תמונת פרופיל ושם מלא לצורך זיהוי פשוט יותר בין כל התכונות השונות.",
     "Add your profile information! Set a full name for easier recognition across all features." : "נא להוסיף את פרטי הפרופיל שלך! ניתן להגדיר שם מלא כדי להקל על הזיהוי בין כל התכונות השונות.",
     "Add your profile information! Set a profile picture for easier recognition across all features." : "נא להוסיף את פרטי הפרופיל שלך! ניתן להגדיר תמונת פרופיל לצורך זיהוי פשוט יותר בין כל התכונות השונות.",
@@ -21,20 +20,16 @@ OC.L10N.register(
     "Sync tasks from various devices with your Nextcloud and edit them online." : "סנכרון משימות בין מכשירים שונים עם ה־Nextcloud שלך ולערוך אותן באופן מקוון.",
     "About" : "על אודות",
     "A welcome and introduction wizard for Nextcloud" : "אשף קבלת פנים והיכרות ל־Nextcloud",
-    "Start using Nextcloud" : "להתחיל להשתמש ב־Nextcloud",
     "Extend your cloud" : "הרחבת הענן שלך",
-    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "ניתן למצוא למעלה מ־100 יישומונים בחנות היישומונים של Nextcloud כדי להתאים את הענן לצרכיך:",
     "Groupware apps like Calendar, Contacts, Mail" : "יישומונים לעבודה קבוצתית כמו לוח שנה, אנשי קשר, דוא״ל",
     "Communication with Nextcloud Talk" : "תקשורת עם Nextcloud Talk",
     "Collaboration apps for document editing" : "יישומוני שיתופי פעולה לעריכת מסמכים",
     "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "תכונות אימות ואבטחה כגון אימות דו־שלבי, SSO והגנה מפני כופרות",
-    "Browse the app store" : "עיון בחנות היישומונים",
     "Stay in sync" : "תמיד מסונכרן",
     "Nextcloud gives you access to your files wherever you are." : "עם Nextcloud יש לך גישה לקבצים שלך מכל מקום.",
     "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "הלקוחות הפשוטים לשימוש זמינים לכל הפלטפורמות לשולחן העבודה ולנייד ללא עלות!",
     "Get the apps to sync your files" : "ניתן להוריד את היישומים כדי לסנכרן את הקבצים שלך",
     "Desktop client" : "לקוח לשולחן עבודה",
-    "Android app" : "יישומון Android",
     "iOS app" : "יישומון iOS",
     "Connect your desktop apps to %s" : "חיבור אפליקציית המחשב האישי אל %s",
     "Connect your calendar" : "חיבור היומן שלך",
@@ -61,8 +56,11 @@ OC.L10N.register(
     "Learn more about %s" : "מידע נוסף על %s",
     "Connect other apps to %s" : "חיבור של יישומונים אחרים אל %s",
     "Server address" : "כתובת שרת",
+    "Use this link to connect your apps and desktop client to this server:" : "יש להשתמש בקישור הזה כדי לחבר את היישומונים ואת לקוח שולחן העבודה שלך לשרת הזה:",
     "Copy link" : "העתקת קישור",
-    "Previous" : "הקודם",
-    "Next" : "הבא"
+    "Start using Nextcloud" : "להתחיל להשתמש ב־Nextcloud",
+    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "ניתן למצוא למעלה מ־100 יישומונים בחנות היישומונים של Nextcloud כדי להתאים את הענן לצרכיך:",
+    "Browse the app store" : "עיון בחנות היישומונים",
+    "Android app" : "יישומון Android"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
