@@ -3,6 +3,11 @@ OC.L10N.register(
     {
     "Error parsing log" : "Günlük işlenirken sorun çıktı",
     "Caused by " : "Nedeni",
+    "Debug" : "Hata ayıklama",
+    "Info" : "Bilgiler",
+    "Warning" : "Uyarı",
+    "Error" : "Hata",
+    "Fatal" : "Kritik",
     "Copy" : "Kopyala",
     "Copy raw" : "Ham olarak kopyala",
     "Copy formatted" : "Biçim ile kopyala",
@@ -13,12 +18,14 @@ OC.L10N.register(
     "App" : "Uygulama",
     "Message" : "İleti",
     "Time" : "Zaman",
+    "Load log file …" : "Günlük dosyasını yükle …",
+    "Invalid log file" : "Günlük dosyası geçersiz",
     "Log levels" : "Günlük düzeyleri",
     "Log content" : "Günlük içeriği",
     "Live update" : "Canlı güncelleme",
     "Download logs" : "Günlüğü indir",
     "Logging" : "Günlükleme",
-    "Log Reader" : "Günlük Okuyucu",
+    "Log Reader" : "Günlük okuyucu",
     "A log reader for Nextcloud" : "Nextcloud günlük okuyucusu",
     "Log reader for Nextcloud" : "Nextcloud günlük okuyucusu"
 },
