@@ -8,8 +8,14 @@ OC.L10N.register(
     "Users" : "Brukarare",
     "Groups" : "Grupper",
     "Links" : "Lenker",
+    "Copied!" : "Kopiert!",
+    "Not supported!" : "Ikkje støtta!",
+    "Press ⌘-C to copy." : "Trykk  ⌘-C for å kopiere.",
+    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
     "Monitoring" : "Overvåker",
+    "Size" : "Storleik",
     "Files:" : "Filar:",
+    "Status" : "Status",
     "Active users" : "Aktive brukarare",
     "Shares" : "Delingar",
     "Memory Limit:" : "Minne grense:",
@@ -17,12 +23,6 @@ OC.L10N.register(
     "Database" : "Database",
     "Type:" : "Type:",
     "Size:" : "Storleik:",
-    "External monitoring tool" : "Eksternt monoitor verktøy",
-    "Last 24 hours" : "Siste 24 timer",
-    "Last 1 hour" : "Siste time",
-    "Last 5 mins" : "Siste 5 minutt",
-    "Memory usage" : "Minne bruk",
-    "Storage" : "Lagring",
-    "Users:" : "Brukarare:"
+    "External monitoring tool" : "Eksternt monoitor verktøy"
 },
 "nplurals=2; plural=(n != 1);");
