@@ -67,6 +67,7 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Fruni una crae amministrativa de riprìstinu; si nono, s'ant a perdere totu is datos de utente.",
     "Wrong admin recovery password. Please check the password and try again." : "Crae amministrativa de riprìstinu isballiada. Controlla·dda e torra a proare.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Su motore non suportat su càmbiu de crae, ma sa crae de tzifradura de s'utente est agiornada.",
+    "installing and updating apps via the App Store or Federated Cloud Sharing" : "installatzione e agiornamentu de is aplicatziones tràmite sa butega de is aplicatziones o sa cumpartzidura in sa nue federada",
     "Federated Cloud Sharing" : "Cumpartzidura in sa nue federada",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL est impreende una versione %1$sagiornada (%2$s). Agiorna su sistema operativu tuo, si nono funtzionalidades comente %3$s no ant a funtzionare.",
     "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Impossìbile a determinare si sa versione TLS de cURL est betza o nono, ca ddoe at àpidu un'errore durante sa dimanda HTTPS in https://nextcloud.com. Controlla s'archìviu de registru de nextcloud pro àteros detàllios.",
@@ -119,6 +120,9 @@ OC.L10N.register(
     "Sharing" : "Cumpartzidura",
     "Personal info" : "Informatziones personales",
     "Mobile & desktop" : "Mòbile e de iscrivania",
+    "Email server" : "Serbidore posta eletrònica",
+    "Security & setup warnings" : "Avisos de seguresa e impostatziones",
+    "Background jobs" : "Atividades de background",
     "Create" : "Crea",
     "Change" : "Càmbia",
     "Delete" : "Cantzella",
@@ -132,6 +136,7 @@ OC.L10N.register(
     "MySQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MySQL 8.0 or MariaDB 10.2 or higher." : "Est impreada sa versione \"%s\" de MySQL. Nextcloud 21 no at a suportare prus custa versione e rechedet MySQL 8.0 o MariaDB 10.2 o superiore.",
     "PostgreSQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires PostgreSQL 9.6 or higher." : "Est impreada sa versione \"%s\" de PostgreSQL. Nextcloud 21 no at a suportare prus custa versione e rechedet PostgreSQL 9.6 o superiore.",
     "Nextcloud settings" : "Impostatziones de Nextcloud",
+    "None" : "Perunu",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "S'autenticatzione a duos fatores si podet aplicare a totu is utentes e grupos ispetzìficos. Si non tenent unu frunidore a duos fatores cunfiguradu, no ant a pòdere intrare in su sistema.",
     "Enforce two-factor authentication" : "Àplica s'autenticatzione a duos fatores",
     "Limit to groups" : "Lìmita a grupos",
@@ -183,6 +188,10 @@ OC.L10N.register(
     "Google Chrome for Android" : "Google Chrome pro Android",
     "iPhone" : "iPhone",
     "iPad" : "iPad",
+    "{productName} iOS app" : "{productName} aplicatzione iOS ",
+    "{productName} Android app" : "{productName} aplicatzione Android",
+    "{productName} Talk for iOS" : "{productName} Talk pro iOS",
+    "{productName} Talk for Android" : "{productName} Talk pro Android",
     "Sync client - {os}" : "Cliente de sincronizatzione - {os}",
     "This session" : "Custa sessione",
     "Device" : "Dispositivu",
@@ -207,13 +216,23 @@ OC.L10N.register(
     "Copied!" : "Copiadu!",
     "Copy" : "Còpia",
     "Could not copy app password. Please copy it manually." : "No at fatu a copiare sa crae. Copia·dda a manu.",
+    "Email options" : "Optziones de posta eletrònica",
+    "Primary email for password reset and notifications" : "Indiritzu de posta eletrònica printzipale pro torrare a impostare sa crae e retzire notìficas",
+    "Remove primary email" : "Boga•nche s'indiritzu de posta eletrònica printzipale",
+    "Delete email" : "Cantzella indiritzu de posta eletrònica",
+    "Your email address" : "Indiritzu tuo de posta eletrònica",
+    "Additional email address {index}" : "Segundu indiritzu de posta eletrònica {index}",
+    "No email address set" : "Perunu indiritzu de posta eletrònica impostadu",
+    "Language" : "Limba",
+    "Help translate" : "Agiuda a tradùere",
+    "No language set" : "Peruna limba impostada",
+    "Add" : "Agiunghe",
     "You do not have permissions to see the details of this user" : "Non tenes is permissos pro bìdere is detàllios de s'utente",
     "Add new password" : "Agiunghe una crae noa",
     "Add new email address" : "Agiunghe un'indiritzu nou de posta eletrònica",
     "Add user to group" : "Agiunghe un'utente a unu grupu",
     "Set user as admin for" : "Include a un'utente in s'amministratzione pro",
     "Select user quota" : "Seletziona cuota utente",
-    "No language set" : "Peruna limba impostada",
     "Delete user" : "Cantzella utente",
     "Wipe all devices" : "Cantzella totu is dispositivos",
     "Disable user" : "Disativa utente",
@@ -238,20 +257,17 @@ OC.L10N.register(
     "Add a new user" : "Agiunghe un'utèntzia noa",
     "Group admin for" : "In amministratzione pro su grupu",
     "Quota" : "Cuota",
-    "Language" : "Limba",
     "User backend" : "Motore utente",
     "Storage location" : "Positzione de s'archiviatzione",
     "Last login" : "Ùrtimu atzessu",
     "No users in here" : "Peruna utèntzia inoghe",
     "Default quota" : "Cuota predefinida",
     "Common languages" : "Limbas comunes",
-    "All languages" : "Totu is limbas",
     "Password change is disabled because the master key is disabled" : "Su càmbiu de sa crae est disativadu ca sa crae printzipale est disativada",
     "Passwordless authentication requires a secure connection." : "S'autenticatzione chene crae rechedet una connessione segura.",
     "Add WebAuthn device" : "Agiunghe dispositivu WebAuthn",
     "Please authorize your WebAuthn device." : "Autoriza su dispositivu WebAuthn tuo.",
     "Name your device" : "Nùmena su dispositivu",
-    "Add" : "Agiunghe",
     "Adding your device …" : "Agiunghende su dispositivu tuo ...",
     "Server error while trying to add WebAuthn device" : "Errore de su serbidore chirchende de agiùnghere su dispositivu WebAuthn",
     "Server error while trying to complete WebAuthn device registration" : "Errore de su serbidore chirchende de cumpletare sa registratzione de su dispositivu WebAuthn",
@@ -273,7 +289,7 @@ OC.L10N.register(
     "by {author}\n{license}" : "de {author}\n{license}",
     "Enter group name" : "Inserta nùmene de su grupu",
     "Add group" : "Agiunghe grupu",
-    "Everyone" : "Chie chi siat",
+    "Active users" : "Utèntzias ativas",
     "Admins" : "Amministratzione",
     "Disabled users" : "Disativa utentes",
     "Remove group" : "Boga·nche grupu",
@@ -286,24 +302,29 @@ OC.L10N.register(
     "Send email to new user" : "Imbia messàgiu de posta a utèntzia noa",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Ses acanta de nche bogare su grupu {group}. Is utèntzias NO s'ant a cantzellare.",
     "Please confirm the group removal " : "Cunfirma de bogare su grupu",
+    "Address" : "Indiritzu",
+    "Full name" : "Nùmene cumpletu",
+    "Phone number" : "Nùmeru de telèfonu",
+    "Twitter" : "Twitter",
+    "Website" : "Situ ìnternet",
     "Download and enable" : "Iscàrriga e ativa",
     "Enable" : "Ativa",
     "Enable untested app" : "Ativa aplicatzione non verificada",
+    "The app will be downloaded from the App Store" : "S'aplicatzione s'at a iscarrigare dae sa butega de is aplicatziones",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Custa aplicatzione no est marcada comente cumpatìbile cun sa versione tua de Nextcloud. Si sighis, as a pòdere installare s'aplicatzione. Càstia ca podet èssere chi non funtzionet comente prevìdidu.",
     "Never" : "Mai",
     "An error occured during the request. Unable to proceed." : "Ddoe at àpidu un'errore in sa dimanda. Impossìbile a sighire.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "S'aplicatzione est istada ativada ma tenet bisòngiu de un'agiornamentu. T'amus a deretare a sa pàgina de agiornamentu tra 5 segundos.",
     "App update" : "Agiornamentu de s'aplicatzione",
+    "Error: This app cannot be enabled because it makes the server unstable" : "Errore: Custa aplicatzione non si podet ativare ca faghet su serbidore no istàbile",
     "Administrator documentation" : "Documentatzione amministratzione",
     "Documentation" : "Documentatzione",
     "Forum" : "Forum",
-    "None" : "Perunu",
     "Login" : "Atzessu",
     "Plain" : "Simpre",
     "NT LAN Manager" : "NT LAN Manager",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
-    "Email server" : "Serbidore posta eletrònica",
     "Open documentation" : "Aberi documentatzione",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Est importante a impostare custu serbidore pro imbiare messàgios de posta eletrònica, pro re-impostare sa crae e pro is notìficas. ",
     "Send mode" : "Modalidade de imbiu",
@@ -320,7 +341,6 @@ OC.L10N.register(
     "Save" : "Sarva",
     "Test email settings" : "Proa impostatziones de sa posta eletrònica",
     "Send email" : "Imbia messàgiu de posta eletrònica",
-    "Security & setup warnings" : "Avisos de seguresa e impostatziones",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Est importante pro sa seguresa e s'esecutzione de s'istàntzia tua chi totu siat cunfiguradu bene. Pro t'agiudare, semus faghende controllos automàticos. Càstia sa documentatzione in ligòngiu pro àteras informatziones.",
     "All checks passed." : "Passados totu is controllos.",
     "There are some errors regarding your setup." : "B'at errores in sa cunfiguratzione tua.",
@@ -331,16 +351,115 @@ OC.L10N.register(
     "Version" : "Versione",
     "Two-Factor Authentication" : "Autenticatzione a duos fatores",
     "Server-side encryption" : "Tzifradura ladu serbidore",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Sa tzifradura ladu serbidore permitit de tzifrare is archìvios chi sunt carrigados in custu serbidore. Bi sunt limitatziones comente prestatziones prus bàscias, tando ativa•ddu isceti chi est netzessàriu.",
+    "Enable server-side encryption" : "Ativa  tzifradura ladu serbidore",
+    "Please read carefully before activating server-side encryption: " : "Leghe bene antis de ativare sa tzifradura ladu serbidore:",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una borta chi sa tzifradura est ativada, totu is archìvios carrigados in su serbidore dae cussu momentu ant a èssere tzifrados in su serbidore. S'at a pòdere disativare sa tzifradura a pustis, si su mòdulu de tzifradura ativu ddu permitit, e totu is pre-cunditziones (comente s'impostatzione de una crae de recùperu) sunt cumproadas.",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Sa tzifradura a sa sola no assegurat sa seguresa de su sistema. Càstia sa documentatzione pro àteras informatziones subra su funtzionamentu de s'aplicatzione pro sa tzifradura, e is genias de impreu suportadas.",
+    "Be aware that encryption always increases the file size." : "Regorda ca sa tzifradura creschet semper sa mannària de s'archìviu.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Benit semper a bene a creare còpias de seguresa regulares de is datos tuos, in casu de tzifradura assegura•ti de creare còpia de is craes de tzfradura paris cun is datos tuos.",
+    "This is the final warning: Do you really want to enable encryption?" : "Custu est s'ùrtimu avisu : a beru boles ativare sa tzifradura?",
+    "Enable encryption" : "Ativa tzifradura",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Perunu mòdulu de tzifradura carrigadu, ativa sa tzifradura in su menu de is aplicatziones.",
+    "Select default encryption module:" : "Seletziona mòdulu de tzifradura predefinidu:",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Depes tramudare is craes de tzifradura dae sa tzifradura betza (ownCloud <= 8.0) a sa noa. Ativa su \"Mòdulu de tzifradura predefinidu\" e esecuta 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Depes tramudare is craes de tzifradura dae sa tzifradura betza (ownCloud <= 8.0) a sa noa.",
+    "Start migration" : "Cumintza sa tràmuda",
+    "Last job execution ran %s. Something seems wrong." : "S'ùrtima atividade de esecutzione est partida %s. Calicuna cosa paret isballiada.",
+    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "B'at atividades chi no sunt istadas esecutadas dae %s. Cunsidera de crèschere sa frecuèntzia de esecutzione.",
+    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "B'at atividades chi no sunt istadas esecutadas dae %s. Cunsidera de cambiare a su cron de sistema.",
+    "Last job ran %s." : "S'ùrtima atividade est partida %s.",
+    "Background job didn’t run yet!" : "S'atividade in segundu pianu no est ancora istada esecutada!",
+    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Pro prestatziones primorosas est importante a cunfigurare in sa manera curreta is atividades in segundu pianu. Pro istàntzias prus mannas 'Cron' est s'impostatzione cussigiada. Càstia sa documentatzione pro àteras informatziones.",
+    "Pick background job setting" : "Sèbera s'impostatzione de s'atividade in segundu pianu",
+    "Execute one task with each page loaded." : "Esecuta una faina cun cada pàgina carrigada.",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php est registradu in unu servìtziu webcron pro cramare cron.php cada 5 minutos tràmite HTTP.",
+    "Use system cron service to call the cron.php file every 5 minutes." : "Imprea su servìtziu cron de sistema pro cramare s'archìviu cron.php cada 5 minutos.",
+    "The cron.php needs to be executed by the system user \"%s\"." : "Su cron.php depet èssere esecutadu dae s'utente de sistema \"%s\".",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Pro esecutare custu, serbit s'estensione PHP POSIX. Càstia {linkstart}documentatzione PHP{linkend} pro àteros detàllios.",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Comente parte de s'amministratzione podes afinigare su cumportamentu de cumpartzidura. Càstia sa documentatzione pro àteras informatziones.",
+    "Allow apps to use the Share API" : "Permite a is aplicatzione de impreare is API de cumpartzidura",
+    "Set default expiration date for shares" : "Imposta sa data de iscadèntzia predefinida pro is cumpartziduras",
+    "Expire after" : "Iscadit pustis de",
+    "day(s)" : "die(s)",
+    "Enforce expiration date" : "Impone data de iscadèntzia",
+    "Set default expiration date for shares to other servers" : "Imposta sa data de iscadèntzia predefinida pro is cumpartziduras a àteros serbidores",
+    "Allow users to share via link and emails" : "Permite a is utentes de cumpartzire tràmite ligòngios e posta eletrònica",
+    "Allow public uploads" : "Permite carrigamentos pùblicos",
+    "Always ask for a password" : "Pedi semper una crae",
+    "Enforce password protection" : "Impone sa bardiadura de sa crae",
+    "Set default expiration date" : "Imposta sa data de iscadèntzia predefinida ",
+    "Exclude groups from creating link shares:" : "Esclude grupos dae sa creatzione de ligòngios de cumpartzidura:",
+    "Allow resharing" : "Permite de torrare a cumpartzire",
+    "Allow sharing with groups" : "Permite cumpartzidura cun grupos",
+    "Restrict users to only share with users in their groups" : "Lìmita is utentes a sa cumpartzidura isceti cun utentes in is grupos issoro",
+    "Exclude groups from sharing" : "Esclude grupos dae sa cumpartzidura",
+    "These groups will still be able to receive shares, but not to initiate them." : "Custos grupos ant a pòdere retzire cumpartziduras, ma no ddas ant a pòdere cumintzare.",
+    "Allow username autocompletion in share dialog" : "Permite sa cumponidura automàtica de su nùmene de utente in sa ventana de cumpartzidura",
+    "Allow username autocompletion to users within the same groups" : "Permite sa cumponidura automàtica de su nùmene de utente a is utentes de su matessi grupu",
+    "Allow username autocompletion to users based on phone number integration" : "Permite sa cumponidura automàtica de su nùmene de utente a is utentes segundu s'integratzione de su nùmeru de telèfonu",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si sa cumponidura automàtica \"matessi grupu\" e \"integratzione de nùmeru de telèfonu\" sunt ativadas, una currispondèntzia in unu de is duas bastat a mustrare s'utente.",
+    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permite sa cumponidura automàtica candu si nche insertat su nùmene cumpletu o s'indiritzu de posta eletrònica (discuidende sa currispondèntzia mancante in sa rubrica e sende in su matessi grupu)",
+    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mustra sa liberatòria in sa pàgina de carrigamentu de su ligòngiu pùblicu (mustradu isceti cando s'archìviu de sa lista est cuadu)",
+    "This text will be shown on the public link upload page when the file list is hidden." : "Custu testu s'at a mustrare in sa pàgina de carrigamentu de su ligòngiu pùblicu cando s'archìviu de sa lista est cuadu.",
+    "Default share permissions" : "Permissos de cumpartzidura predefinidos",
+    "Reasons to use Nextcloud in your organization" : "Resones pro impreare Nextcloud in s'organizatzione tua",
+    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Isvilupadu dae {communityopen}comunidadeNextcloud {linkclose}, su {githubopen}còdighe de orìgine{linkclose} est lissentziadu pro {licenseopen}AGPL{linkclose}.",
+    "Like our Facebook page" : "Pone•ddi M'agradat a sa pàgina Facebook nostra",
+    "Follow us on Twitter" : "Sighi•nosi in Twitter",
+    "Follow us on Mastodon" : "Sighi•nos in Mastodon",
+    "Check out our blog" : "Leghe·ti su blog nostru",
+    "Subscribe to our newsletter" : "Iscrie·ti a sa lista de messàgios nostra",
+    "Profile picture" : "Imàgine de profilu",
+    "Change privacy level of profile picture" : "Càmbia su livellu de riservadesa de s'imàgine de profilu",
+    "Upload new" : "Càrriga noa",
+    "Select from Files" : "Seletziona dae Archìvios",
+    "Remove image" : "Boga•nche s'imàgine",
+    "png or jpg, max. 20 MB" : "png o jpg, max. 20 MB",
+    "Picture provided by original account" : "Imàgine frunida dae su contu originale",
+    "Choose as profile picture" : "Sèbera comente imàgine de profilu",
+    "You are a member of the following groups:" : "Faghes parte de custos grupos:",
+    "You are using <strong>%s</strong>" : "Ses impreende <strong>%s</strong>",
+    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Ses impreende <strong>%1$s</strong> de<strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Change privacy level of phone number" : "Càmbia su livellu de riservadesa de su nùmeru de telèfonu",
+    "Your phone number" : "Nùmero tuo de telèfonu",
+    "Change privacy level of address" : "Càmbia su livellu de riservadesa de s'indiritzu",
+    "Your postal address" : "Indiritzu postale tuo",
+    "Change privacy level of website" : "Càmbia su livellu de riservadesa de su situ web",
+    "It can take up to 24 hours before the account is displayed as verified." : "Diant pòdere serbire 24 oras antis de visualizare su contu comente cumproadu.",
+    "Link https://…" : "Ligòngiu https://…",
+    "Change privacy level of Twitter profile" : "Càmbia su livellu de riservadesa de su profilu Twitter",
+    "Twitter handle @…" : "Utente de Twitter @...",
+    "Locale" : "Localizatzione",
+    "Current password" : "Crae currente",
+    "New password" : "Crae noa",
     "Change password" : "Càmbia crae",
-    "Contacts" : "Cuntatos",
+    "Use a second factor besides your password to increase security for your account." : "Imprea unu segundu fatore a parte sa crae tua pro crèschere sa seguresa de su contu tuo.",
+    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si impreas aplicatziones de sa de tres partes pro ti connètere a Nextcloud, assegura•ti de creare e cunfigurare una crae pro cada aplicatzione antis de ativare su segundu fatore de autenticatzione.",
+    "Don't synchronize to servers" : "No sincronizes cun perunu serbidore",
+    "Trusted" : "Fidadu",
+    "Public" : "Pùblicu",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "installatzione e s'agiornamentu de is aplicatziones tràmite sa butega de is aplicatziones o sa cumpartzidura in sa nue federada",
-    "The app will be downloaded from the app store" : "S'aplicatzione s'at a iscarrigare dae sa butega de is aplicatziones",
     "Nextcloud iOS app" : "Aplicatzione Nextcloud pro iOS",
     "Nextcloud Android app" : "Aplicatzione Nextcloud pro Android",
     "Nextcloud Talk for iOS" : "Nextcloud Talk pro iOS",
     "Nextcloud Talk for Android" : "Nextcloud Talk pro Android",
+    "Add user in group" : "Agiunghe un'utente in su grupu",
     "Close" : "Serra",
+    "All languages" : "Totu is limbas",
+    "Everyone" : "Chie chi siat",
+    "The app will be downloaded from the app store" : "S'aplicatzione s'at a iscarrigare dae sa butega de is aplicatziones",
     "Error: This app can not be enabled because it makes the server unstable" : "Errore: Custa aplicatzione non si podet ativare ca faghet su serbidore no istàbile",
-    "mail" : "posta"
+    "mail" : "posta",
+    "Expire after " : "Iscadit pustis de",
+    "days" : "dies",
+    "Allow users to share via link" : "Permite a is utentes de cumpartzire tràmite ligòngios",
+    "Set default expiration date for link shares" : "Imposta sa data de iscadèntzia predefinida pro is ligòngios de cumpartzidura",
+    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Permite sa cumponidura automàtica in is ventanas de cumpartzidura (si custu est disativadu at a tocare a nche insertare su nùmene cumpletu o s'indiritzu de posta eletrònica)",
+    "Restrict username autocompletion to users within the same groups" : "Lìmita sa cumponidura automàtica de su nùmene de utente a is utentes de su matessi grupu",
+    "No display name set" : "Nùmene visualizadu no impostadu",
+    "For password reset and notifications" : "Pro impostare torra sa crae e notìficas ",
+    "Change privacy level of full name" : "Càmbia su livellu de riservadesa de su nùmene cumpletu",
+    "Change privacy level of email" : "Càmbia su livellu de riservadesa de sa posta eletrònica"
 },
 "nplurals=2; plural=(n != 1);");
