@@ -113,12 +113,16 @@ OC.L10N.register(
     "Personal" : "Osebno",
     "Administration" : "Skrbništvo",
     "Additional settings" : "Dodatne nastavitve",
+    "Admin privileges" : "Dovoljenja skrbnika",
     "Groupware" : "Skupinsko delo",
     "Overview" : "Splošni pregled",
     "Basic settings" : "Osnovne nastavitve",
     "Sharing" : "Souporaba",
     "Personal info" : "Osebni podatki",
     "Mobile & desktop" : "Mobilni in namizni dostop",
+    "Email server" : "Poštni strežnik",
+    "Security & setup warnings" : "Varnost in namestitvena opozorila",
+    "Background jobs" : "Opravila v ozadju",
     "Create" : "Ustvarjanje",
     "Change" : "Spreminjanje",
     "Delete" : "Brisanje",
@@ -132,6 +136,10 @@ OC.L10N.register(
     "MySQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MySQL 8.0 or MariaDB 10.2 or higher." : "V uporabi je različica podatkovne zbirke MySQL »%s«. Z namestitvijo Nextcloud 21 ta ni več podprta. Sistem zahteva nadgradnjo zbirke na različico MySQL 8.0, MariaDB 10.2 ali višje.",
     "PostgreSQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires PostgreSQL 9.6 or higher." : "V uporabi je različica podatkovne zbirke PostgreSQL »%s«. Z namestitvijo Nextcloud 21 ta ni več podprta. Sistem zahteva nadgradnjo zbirke na različico PostgreSQL 9.6 ali višjo.",
     "Nextcloud settings" : "Nastavitve Nextcloud",
+    "Administration privileges" : "Skrbniška dovoljenja",
+    "Here you can decide which group can access certain sections of the administration settings." : "Na tem mestu je mogoče določiti, katera skupina ima dostop do določenih možnosti skrbniških nastavitev.",
+    "None" : "Brez",
+    "Unable to modify setting" : "Ni mogoče spremeniti nastavitve",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvostopenjsko overjanje je mogoče vsiliti za vse uporabnike in določene skupine. Če za tovrstno prijavo nimajo nastavljenega ustreznega ponudnika, se v sistem ne bodo uspeli povezati.",
     "Enforce two-factor authentication" : "Vsili dvo-stopenjsko overjanje",
     "Limit to groups" : "Omeji na skupine",
@@ -148,8 +156,8 @@ OC.L10N.register(
     "Update to {version}" : "Posodobi na različico {version}",
     "Remove" : "Odstrani",
     "Disable" : "Onemogoči",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja NextCloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja NextCloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcoud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerazrešenih odvisnosti:",
     "View in store" : "Pokaži v trgovini",
     "Visit website" : "Odpri spletno stran",
@@ -183,6 +191,10 @@ OC.L10N.register(
     "Google Chrome for Android" : "Google Chrome za Android",
     "iPhone" : "iPhone",
     "iPad" : "iPad",
+    "{productName} iOS app" : "{productName} za iOS",
+    "{productName} Android app" : "{productName} za Android",
+    "{productName} Talk for iOS" : "{productName} Talk za iOS",
+    "{productName} Talk for Android" : "{productName} Talk za Android",
     "Sync client - {os}" : "Usklajevalnik – {os}",
     "This session" : "Ta seja",
     "Device" : "Naprava",
@@ -207,13 +219,45 @@ OC.L10N.register(
     "Copied!" : "Kopirano!",
     "Copy" : "Kopiraj",
     "Could not copy app password. Please copy it manually." : "Gesla programa ni mogoče kopirati. Storite to ročno.",
+    "Your biography" : "Biografija",
+    "Unable to update biography" : "Ni mogoče posodobiti biografije",
+    "Your full name" : "Polno ime",
+    "Unable to update full name" : "Ni mogoče posodobiti polnega imena",
+    "No full name set" : "Ni nastavljenega polnega imena",
+    "Email options" : "Možnosti elektronske pošte",
+    "Primary email for password reset and notifications" : "Osnovni elektronski naslov za obnavljanje gesla in obvestila",
+    "Remove primary email" : "Odstrani osnovni elektronski naslov",
+    "Delete email" : "Izbriši elektronski naslov",
+    "Unset as primary email" : "Odstrani oznako osnovnega elektronskega naslova",
+    "This address is not confirmed" : "Ta naslov ni potrjen",
+    "Set as primary email" : "Nastavi kot osnovni elektronski naslov",
+    "Your email address" : "Osebni elektronski naslov",
+    "Additional email address {index}" : "Dodatni elektronski naslov {index}",
+    "Unable to delete primary email address" : "Ni mogoče izbrisati osnovnega elektronskega naslova",
+    "Unable to update primary email address" : "Ni mogoče posodobiti osnovnega elektronskega naslova",
+    "Unable to add additional email address" : "Ni mogoče dodati dodatnega elektronskega naslova",
+    "Unable to update additional email address" : "Ni mogoče posodobiti dodatnega elektronskega naslova",
+    "Unable to delete additional email address" : "Ni mogoče izbrisati dodatnega elektronskega naslova",
+    "No email address set" : "Poštni naslov ni nastavljen",
+    "Additional emails" : "Dodatni elektronski naslovi",
+    "Your headline" : "Vaš naslov",
+    "Unable to update headline" : "Ni mogoče posodobiti naslova",
+    "Language" : "Jezik",
+    "Help translate" : "Sodelujte pri prevajanju",
+    "Unable to update language" : "Ni mogoče posodobiti jezika",
+    "No language set" : "Jezik ni nastavljen",
+    "Your organisation" : "Ustanova",
+    "Unable to update organisation" : "Ni mogoče posodobiti imena ustanove",
+    "Enable Profile" : "Omogoči profil",
+    "Unable to update profile enabled state" : "Ni mogoče posodobiti omogočenega stanja profila",
+    "Your role" : "Vloga",
+    "Add" : "Dodaj",
     "You do not have permissions to see the details of this user" : "Ni ustreznih dovoljenj za pregled podatkov uporabnika",
     "Add new password" : "Vpis gesla",
     "Add new email address" : "Vpis elektronskega naslova",
     "Add user to group" : "Dodaj uporabnika v skupino",
     "Set user as admin for" : "Nastavi uporabnika kot skrbnika za",
     "Select user quota" : "Količinska omejitev prostora",
-    "No language set" : "Jezik ni nastavljen",
     "Delete user" : "Izbriši uporabnika",
     "Wipe all devices" : "Varnostno izbriši vse naprave",
     "Disable user" : "Onemogoči uporabnika",
@@ -238,20 +282,18 @@ OC.L10N.register(
     "Add a new user" : "Dodaj uporabnika",
     "Group admin for" : "Skrbnik skupine za",
     "Quota" : "Količinska omejitev",
-    "Language" : "Jezik",
     "User backend" : "Uporabniški ozadnji program",
     "Storage location" : "Mesto shrambe",
     "Last login" : "Zadnja prijava",
     "No users in here" : "Ni še vključenih uporabnikov",
     "Default quota" : "Privzeta omejitev",
     "Common languages" : "Splošni jeziki",
-    "All languages" : "Vsi jeziki",
+    "Other languages" : "Drugi jeziki",
     "Password change is disabled because the master key is disabled" : "Spreminjanje gesla je onemogočeno, ker je onemogočen tudi glavni šifrirni ključ",
     "Passwordless authentication requires a secure connection." : "Brezgeselna overitev zahteva varno povezavo.",
     "Add WebAuthn device" : "Dodaj napravo WebAuthn",
     "Please authorize your WebAuthn device." : "Overite napravo WebAuthn",
     "Name your device" : "Naziv naprave",
-    "Add" : "Dodaj",
     "Adding your device …" : "Poteka dodajanje naprave ..",
     "Server error while trying to add WebAuthn device" : "Prišlo je do strežniške napake med dodajanjem naprave WebAuthn",
     "Server error while trying to complete WebAuthn device registration" : "Prišlo je do strežniške napake med zaključevanjem vpisovanja naprave WebAuthn",
@@ -273,7 +315,7 @@ OC.L10N.register(
     "by {author}\n{license}" : "Razvoj: {author}\nDovoljenje: {license}",
     "Enter group name" : "Vpis imena skupine",
     "Add group" : "Dodaj skupino",
-    "Everyone" : "Vsi",
+    "Active users" : "Dejavni uporabniki",
     "Admins" : "Skrbniki",
     "Disabled users" : "Onemogočeni uporabniki",
     "Remove group" : "Odstrani skupino",
@@ -286,6 +328,19 @@ OC.L10N.register(
     "Send email to new user" : "Pošlji sporočilo novemu uporabniku",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Odstranili boste skupino {group}. Uporabniki ne bodo odstranjeni.",
     "Please confirm the group removal " : "Potrditi je treba odstranjevanje skupine",
+    "Address" : "Naslov",
+    "Avatar" : "Podoba",
+    "Full name" : "Polno ime",
+    "Additional email" : "Dodatni elektronski naslov",
+    "Headline" : "Naslov",
+    "Organisation" : "Ustanova",
+    "Phone number" : "Telefonska številka",
+    "Profile" : "Profil",
+    "Role" : "Vloga",
+    "Twitter" : "Račun Twitter",
+    "Website" : "Spletna stran",
+    "Show to everyone" : "Pokaži vsem",
+    "Hide" : "Skrij",
     "Download and enable" : "Prejmi in omogoči",
     "Enable" : "Omogoči",
     "Enable untested app" : "Omogoči nepreizkušen program",
@@ -294,16 +349,15 @@ OC.L10N.register(
     "An error occured during the request. Unable to proceed." : "Med izvajanjem zahteve je prišlo do napake, zato ni mogoče nadaljevati.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Program je omogočen, vendar zahteva posodobitev. Po nekaj sekundah boste preusmerjeni na stran za posodobitev.",
     "App update" : "Posodobitev programa",
+    "Error: This app cannot be enabled because it makes the server unstable" : "Napaka: tega programa ni mogoče namestiti, ker povzroča nestabilnost strežnika.",
     "Administrator documentation" : "Skrbniška dokumentacija",
     "Documentation" : "Dokumentacija",
     "Forum" : "Forum",
-    "None" : "Brez",
     "Login" : "Prijava",
     "Plain" : "Besedilno",
     "NT LAN Manager" : "Upravljalnik NT LAN",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
-    "Email server" : "Poštni strežnik",
     "Open documentation" : "Odprta dokumentacija",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Strežnik mora biti za pošiljanje sporočil ustrezno nastavljen. Velja tudi za pošiljanje povezav za ponastavitev gesla..",
     "Send mode" : "Način pošiljanja",
@@ -320,7 +374,6 @@ OC.L10N.register(
     "Save" : "Shrani",
     "Test email settings" : "Preizkus nastavitev elektronske pošte",
     "Send email" : "Pošlji elektronsko sporočilo",
-    "Security & setup warnings" : "Varnost in namestitvena opozorila",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zaradi varnosti in optimizacije delovanja je pomembno, da je sistem pravilno nastavljen. Za preverjanj se nekateri preizkusi izvajajo samodejno. Več podrobnosti je zabeleženih v dokumentaciji. ",
     "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
     "There are some errors regarding your setup." : "Med preverjanjem je bilo zaznanih je nekaj napak namestitve.",
@@ -345,7 +398,6 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Preseliti je treba šifrirne ključe iz starega sistema (ownCloud ≤ 8.0) na novega. Omogočite možnost »Privzeti šifrirni modul« in zaženite ukaz »occ encryption:migrate«.",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Preseliti je treba šifrirne ključe iz starega sistema (ownCloud <= 8.0) na novega.",
     "Start migration" : "Začni selitev",
-    "Background jobs" : "Opravila v ozadju",
     "Last job execution ran %s. Something seems wrong." : "Zadnji poskus izvedbe je bil izveden %s. Kaže, da je nekaj narobe.",
     "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Nekatera opravila niso bila izvedena od %s. Priporočljivo je povečati pogostost izvajanja.",
     "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Nekatera opravila niso bila izvedena od %s. Priporočljivo je preklopiti na sistemska opravila cron.",
@@ -361,7 +413,8 @@ OC.L10N.register(
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Skrbnik lahko prilagodi možnosti souporabe. Več podrobnosti je zapisanih v dokumentaciji.",
     "Allow apps to use the Share API" : "Dovoli programom uporabo vmesnika API souporabe",
     "Set default expiration date for shares" : "Nastavi privzeti datuma poteka za mesta souporabe",
-    "days" : "dneh.",
+    "Expire after" : "Poteče po",
+    "day(s)" : "dneh",
     "Enforce expiration date" : "Vsili datum preteka",
     "Set default expiration date for shares to other servers" : "Nastavi privzeti datuma poteka za mesta souporabe na drugih strežnikih",
     "Allow users to share via link and emails" : "Uporabnikom dovoli omogočanje souporabe s povezavami in elektronskimi sporočili",
@@ -400,67 +453,46 @@ OC.L10N.register(
     "You are a member of the following groups:" : "Omogočeno je članstvo v skupinah:",
     "You are using <strong>%s</strong>" : "Uporabljate <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "V uporabi je <strong>%1$s</strong> od <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Full name" : "Polno ime",
-    "Change privacy level of full name" : "Spremeni pravila zasebnosti za polno ime",
-    "No display name set" : "Prikazno ime ni nastavljeno",
-    "Change privacy level of email" : "Spremeni pravila zasebnosti za elektronski naslov",
-    "Your email address" : "Osebni elektronski naslov",
-    "No email address set" : "Poštni naslov ni nastavljen",
-    "For password reset and notifications" : "Za ponastavitev gesla in obveščanje",
-    "Phone number" : "Telefonska številka",
     "Change privacy level of phone number" : "Spremeni pravila zasebnosti za telefonsko številko",
     "Your phone number" : "Osebna telefonska številka",
-    "Address" : "Naslov",
     "Change privacy level of address" : "Spremeni pravila zasebnosti za naslov",
     "Your postal address" : "Osebni poštni naslov",
-    "Website" : "Spletna stran",
     "Change privacy level of website" : "Spremeni pravila zasebnosti za spletno stran",
     "It can take up to 24 hours before the account is displayed as verified." : "Dokončno overjanje računa lahko traja tudi do 24 ur.",
     "Link https://…" : "Povezava https:// …",
-    "Twitter" : "Račun Twitter",
     "Change privacy level of Twitter profile" : "Spremeni pravila zasebnosti za profil Twitter",
     "Twitter handle @…" : "Twitter @ …",
-    "Help translate" : "Sodelujte pri prevajanju",
     "Locale" : "Jezikovne nastavitve",
     "Current password" : "Trenutno geslo",
     "New password" : "Novo geslo",
     "Change password" : "Spremeni geslo",
     "Use a second factor besides your password to increase security for your account." : "Ob geslu je priporočljivo uporabiti tudi drugo-stopenjsko overitev za večjo varnost računa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Če uporabljate za povezavo z oblakom Nextcloud programe tretjih oseb, najprej ustvarite in nastavite gesla za vsak program, preden omogočite dvostopenjsko overitev.",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Prišlo je do napake. Uvoziti je treba ustrezno ASCII kodirano potrdilo PEM.",
-    "Valid until {date}" : "Veljavno do {date}",
-    "Only visible to local users" : "Vidno le krajevnim uporabnikom",
-    "Only visible to you" : "Vidno le vam",
-    "Contacts" : "Stiki",
-    "Visible to local users and to trusted servers" : "Vidno le krajevnim uporabnikom in odobrenim strežnikom",
+    "Don't synchronize to servers" : "Ne usklajuj s strežniki",
+    "Trusted" : "Varni strežniki",
     "Public" : "Javno",
-    "Will be synced to a global and public address book" : "Podatki bodo usklajeni s splošnimi in javnimi imeniki",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "nameščanje in posodabljanje programov prek programske zbirke ali zveznega oblaka",
-    "by" : "s strani",
-    "The app will be downloaded from the app store" : "Program bo prejet iz zbirke programov",
     "Nextcloud iOS app" : "Program Nextcloud iOS",
     "Nextcloud Android app" : "Program Nextcloud Android",
     "Nextcloud Talk for iOS" : "Nextcloud Talk za iOS",
     "Nextcloud Talk for Android" : "Nextcloud Talk za Android",
     "Add user in group" : "Dodaj uporabnika v skupino",
     "Close" : "Zapri",
+    "All languages" : "Vsi jeziki",
+    "Everyone" : "Vsi",
+    "The app will be downloaded from the app store" : "Program bo prejet iz zbirke programov",
     "Error: This app can not be enabled because it makes the server unstable" : "Napaka: tega programa ni mogoče namestiti, ker povzroča nestabilnost strežnika.",
-    "SSL Root Certificates" : "Korenska potrdila SSL",
-    "Common Name" : "Splošno ime",
-    "Valid until" : "Veljavno do",
-    "Issued By" : "Izdajatelj",
-    "Valid until %s" : "Veljavno do %s",
-    "Import root certificate" : "Uvozi korensko potrdilo",
     "mail" : "pošta",
-    "Execute one task with each page loaded" : "Izvedi eno nalogo z vsako naloženo stranjo.",
     "Expire after " : "Povezava naj preteče po",
+    "days" : "dneh.",
     "Allow users to share via link" : "Uporabnikom dovoli omogočanje souporabe s povezavami",
     "Set default expiration date for link shares" : "Nastavi privzeti datuma poteka za souporabo prek povezave",
-    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Dovoli samodejno dokončanje uporabniškega imena v pogovornem oknu souporabe. Pri onemogočeni možnosti je treba za prikaz vpisati celotno uporabniško ime oziroma elektronski naslov.",
+    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Dovoli samodejno dokončanje uporabniškega imena pri določanju souporabe (sicer je treba vpisati celotno ime ali elektronski naslov).",
     "Restrict username autocompletion to users within the same groups" : "Omeji samodejno dokončanje uporabniškega imena na uporabnike znotraj iste skupine",
-    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Pokaži besedilo izjave o omejitvi odgovornosti pri uporabi javnih povezav za pošiljanje (če je onemogočen prikaz seznama datotek).",
-    "Don't synchronize to servers" : "Ne usklajuj s strežniki",
-    "Trusted" : "Varni strežniki",
-    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Dovoli samodejno dokončanje uporabniškega imena pri določanju souporabe (sicer je treba vpisati celotno ime ali elektronski naslov)."
+    "No display name set" : "Prikazno ime ni nastavljeno",
+    "For password reset and notifications" : "Za ponastavitev gesla in obveščanje",
+    "Change privacy level of full name" : "Spremeni pravila zasebnosti za polno ime",
+    "Change privacy level of email" : "Spremeni pravila zasebnosti za elektronski naslov",
+    "Set as primary mail" : "Nastavi kot osnovni elektronski naslov"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
