@@ -92,6 +92,7 @@ class PersonalInfo implements ISettings {
 	}
 
 	public function getForm(): TemplateResponse {
+		$federationEnabled = $this->appManager->isEnabledForUser('federation');
 		$federatedFileSharingEnabled = $this->appManager->isEnabledForUser('federatedfilesharing');
 		$lookupServerUploadEnabled = false;
 		if ($federatedFileSharingEnabled) {
@@ -124,6 +125,7 @@ class PersonalInfo implements ISettings {
 			'usage_relative' => round($storageInfo['relative']),
 			'quota' => $storageInfo['quota'],
 			'avatarChangeSupported' => $user->canChangeAvatar(),
+			'federationEnabled' => $federationEnabled,
 			'lookupServerUploadEnabled' => $lookupServerUploadEnabled,
 			'avatarScope' => $account->getProperty(IAccountManager::PROPERTY_AVATAR)->getScope(),
 			'displayNameChangeSupported' => $user->canChangeDisplayName(),
@@ -204,7 +206,7 @@ class PersonalInfo implements ISettings {
 	 * @return array
 	 */
 	private function getEmails(IAccount $account): array {
-		$primaryEmail = [
+		$systemEmail = [
 			'value' => $account->getProperty(IAccountManager::PROPERTY_EMAIL)->getValue(),
 			'scope' => $account->getProperty(IAccountManager::PROPERTY_EMAIL)->getScope(),
 			'verified' => $account->getProperty(IAccountManager::PROPERTY_EMAIL)->getVerified(),
@@ -216,14 +218,16 @@ class PersonalInfo implements ISettings {
 					'value' => $property->getValue(),
 					'scope' => $property->getScope(),
 					'verified' => $property->getVerified(),
+					'locallyVerified' => $property->getLocallyVerified(),
 				];
 			},
 			$account->getPropertyCollection(IAccountManager::COLLECTION_EMAIL)->getProperties()
 		);
 
 		$emails = [
-			'primaryEmail' => $primaryEmail,
+			'primaryEmail' => $systemEmail,
 			'additionalEmails' => $additionalEmails,
+			'notificationEmail' => (string)$account->getUser()->getPrimaryEMailAddress(),
 		];
 
 		return $emails;
