@@ -2,15 +2,21 @@ OC.L10N.register(
     "user_status",
     {
     "Recent statuses" : "Recente statussen",
-    "In a meeting" : "Vergadering",
+    "In a meeting" : "In een vergadering",
     "Commuting" : "Woon-werk",
     "Out sick" : "Ziek",
-    "Vacationing" : "vakantie",
+    "Vacationing" : "Op vakantie",
     "Working remotely" : "Thuiswerken",
+    "In a call" : "In gesprek",
     "User status" : "Gebruikersstatus",
-    "What's your status?" : "Wat is je status?",
+    "View profile" : "Bekijk profiel",
+    "Clear status message after" : "Statusbericht wissen na",
+    "What is your status?" : "Wat is jouw status?",
     "Set status" : "Instellen status",
+    "Online status" : "Online status",
     "Status message" : "Statusbericht",
+    "Clear status message" : "Opruimen statusbericht",
+    "Set status message" : "Instellen statusbericht",
     "There was an error saving the status" : "Er is een fout opgetreden bij het bewaren van de status",
     "There was an error clearing the status" : "Er is een fout opgetreden bij het leegmaken van de status",
     "No recent status changes" : "Geen recente statuswijzigingen",
@@ -28,6 +34,8 @@ OC.L10N.register(
     "1 hour" : "1 uur",
     "4 hours" : "4 uur",
     "Mute all notifications" : "Onderdruk alle meldingen",
-    "Clear status after" : "Maak de status leeg na"
+    "Appear offline" : "Toon afwezig",
+    "Clear status after" : "Maak de status leeg na",
+    "What's your status?" : "Wat is je status?"
 },
 "nplurals=2; plural=(n != 1);");
